@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: hotspotter.c,v 1.13 2004/04/25 08:43:18 pwessel Exp $
+ *	$Id: hotspotter.c,v 1.22 2006/04/10 05:47:30 pwessel Exp $
  *
- *   Copyright (c) 1999-2004 by P. Wessel
+ *   Copyright (c) 1999-2006 by P. Wessel
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -107,7 +107,7 @@
  
 #include "spotter.h"
 
-main (int argc, char **argv)
+int main (int argc, char **argv)
 {
 
 	int n_smts;		/* Number of seamounts read */
@@ -135,7 +135,8 @@ main (int argc, char **argv)
 	BOOLEAN truncate_ages = FALSE;	/* Truncate all seamounts ages > upper_age */
 	BOOLEAN finite = FALSE;		/* TRUE if stage pole file contains finite rotation poles instead */
 	BOOLEAN done;
-	
+	BOOLEAN resize = FALSE;
+
 	float *CVA;			/* The CVA surface we seek to calculate */
 
 	double sampling_int_in_km;	/* Sampling interval along flowline (in km) */
@@ -165,42 +166,42 @@ main (int argc, char **argv)
 	char *euler_file = CNULL;	/* Input name of file with stage (Euler) rotations */
 	char line[BUFSIZ];		/* Read buffer */
 	char *processed_node;		/* Pointer to array with TRUE/FALSE values for each grid node */
-	
+
 	FILE *fp;			/* Input data file pointer */
-	
+
 	struct GRD_HEADER CVA_map;	/* Header structure for output CVA grid */
-	
+
 	struct EULER *p;		/* Array of structures with Euler stage rotations */
 
 	/* ------------------- END OF DECLARATIONS ------------------------------------------------------------*/
 
 	argc = GMT_begin (argc, argv);			/* Initialize GMT environment */
-		
+
 	GMT_grd_init (&CVA_map, argc, argv, FALSE);	/* Initialize grid structure */
-	
+
 	GMT_io.in_col_type[0] = GMT_IS_LON;
 	GMT_io.in_col_type[1] = GMT_IS_LAT;
 
 	/* Check command line arguments */
-	
+
 	for (i = 1; i < argc; i++) {
 		if (argv[i][0] == '-') {
 			switch (argv[i][1]) {
-			
+
 				/* Common parameters */
-			
+
 				case 'V':
 				case 'H':
 				case 'R':
 				case ':':
 				case '\0':
-					error += GMT_get_common_args (argv[i], &CVA_map.x_min, &CVA_map.x_max, &CVA_map.y_min, &CVA_map.y_max);
+					error += GMT_parse_common_options (argv[i], &CVA_map.x_min, &CVA_map.x_max, &CVA_map.y_min, &CVA_map.y_max);
 					break;
-				
+
 				/* Supplemental parameters */
-				
+
 				case 'b':
-					error += GMT_io_selection (&argv[i][2]);
+					error += GMT_parse_b_option (&argv[i][2]);
 					break;
 
 				case 'C':	/* Use finite rotation poles */
@@ -225,6 +226,9 @@ main (int argc, char **argv)
 				case 'N':
 					upper_age = atof (&argv[i][2]);
 					break;
+				case 'S':
+					resize = TRUE;
+					break;
 				case 'T':
 					truncate_ages = TRUE;
 					break;
@@ -238,13 +242,13 @@ main (int argc, char **argv)
 			n_files++;
 	}
 
-	if (argc == 1 || GMT_quick) {
+	if (argc == 1 || GMT_give_synopsis_and_exit) {
 		fprintf (stderr, "%s %s - Create CVA image from seamount locations\n\n", GMT_program, SPOTTER_VERSION);
-		fprintf (stderr, "usage: %s [<files>] -E<stage_file> -G<CVAgrid> -I<dx[m|c]>[/<dy>[m|c]]\n", GMT_program);
-		fprintf (stderr, "\t-R<west/east/south/north> [-C] [-D<factor>] [-F] [-H[<nrecs>]] [-N<upper_age>] [-T] [-V] [-:] [-bi[s][<n>]]\n\n");
-		
-		if (GMT_quick) exit (EXIT_FAILURE);
-		
+		fprintf (stderr, "usage: %s [<files>] -E<stage_file> -G<CVAgrid> %s\n", GMT_program, GMT_Id_OPT);
+		fprintf (stderr, "\t%s [-C] [-D<factor>] [-F] [%s] [-N<upper_age>] [-T] [-V] [%s] [%s]\n\n", GMT_Rgeo_OPT, GMT_H_OPT, GMT_t_OPT, GMT_bi_OPT);
+
+		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
+
 		fprintf (stderr, "\t<files> is one or more seamount (x,y,z,r,t) files\n");
 		fprintf (stderr, "\t-G Specify file name for output CVA grid.\n");
 		GMT_explain_option ('H');
@@ -276,7 +280,7 @@ main (int argc, char **argv)
 		fprintf (stderr, "%s: GMT SYNTAX ERROR -G:  Must specify output file\n", GMT_program);
 		error = TRUE;
 	}
-	if (GMT_io.binary[GMT_IN] && gmtdefs.io_header[GMT_IN]) {
+	if (GMT_io.binary[GMT_IN] && GMT_io.io_header[GMT_IN]) {
 		fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data cannot have header -H\n", GMT_program);
 		error++;
 	}
@@ -285,7 +289,7 @@ main (int argc, char **argv)
                 fprintf (stderr, "%s: GMT SYNTAX ERROR.  Binary input data (-bi) must have at least 5 columns\n", GMT_program);
 		error++;
 	}
-	
+
 	if (error) exit (EXIT_FAILURE);
 
 	GMT_put_history (argc, argv);	/* Update .gmtcommands4 */
@@ -348,9 +352,9 @@ main (int argc, char **argv)
 	/* Set flowline sampling interval to 1/2 of the shortest distance between x-nodes */
 
 	sampling_int_in_km = sampling_factor * xinc_r * EQ_RAD * ((fabs (north) > fabs (south)) ? cos (north) : cos (south));
-	if (gmtdefs.verbose) fprintf (stderr, "%s: Flowline sampling interval = %.3lf km\n", GMT_program, sampling_int_in_km);
+	if (gmtdefs.verbose) fprintf (stderr, "%s: Flowline sampling interval = %.3f km\n", GMT_program, sampling_int_in_km);
 
-	if (truncate_ages && gmtdefs.verbose) fprintf (stderr, "%s: Seamount ages truncated to %lg\n", GMT_program, upper_age);
+	if (truncate_ages && gmtdefs.verbose) fprintf (stderr, "%s: Seamount ages truncated to %g\n", GMT_program, upper_age);
 
 	/* Start to read input data */
 
@@ -364,7 +368,7 @@ main (int argc, char **argv)
 	else
 		n_files = 1;
 	n_args = (argc > 1) ? argc : 2;
-	
+
 	done = FALSE;
 
 	n_smts = 0;
@@ -384,9 +388,9 @@ main (int argc, char **argv)
 		}
 
 		if (gmtdefs.verbose) (nofile) ? fprintf (stderr, "%s: Reading stdin\n", GMT_program) : fprintf (stderr, "%s: Working on file %s\n", GMT_program, argv[fno]);
-		
-		if (gmtdefs.io_header[GMT_IN]) for (i = 0; i < gmtdefs.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
-		
+
+		if (GMT_io.io_header[GMT_IN]) for (i = 0; i < GMT_io.n_header_recs; i++) GMT_fgets (line, BUFSIZ, fp);
+
 		while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {	/* Not yet EOF */
 			n_read++;
 			while ((GMT_io.status & GMT_IO_SEGMENT_HEADER) && !(GMT_io.status & GMT_IO_EOF)) {
@@ -400,13 +404,17 @@ main (int argc, char **argv)
 				fprintf (stderr, "%s: Mismatch between actual (%d) and expected (%d) fields near line %d (skipped)\n", GMT_program, n_fields, n_expected_fields, n_read);
 				continue;
 			}
-	
+
 			/* STEP 1: Read information about a single seamount from input record */
 
 			x_smt = in[0] * D2R;	/* Seamount positions in RADIANS */
 			y_smt = in[1] * D2R;
 			z_smt = in[2];
 			r_smt = in[3];
+			if (resize) {
+				z_smt = 1.0;
+				/* r_smt = 2.0 * yinc_r * EQ_RAD; */
+			}
 			if (GMT_is_dnan (in[4])) {	/* Age is NaN, assign value */
 				t_smt = upper_age;
 			}
@@ -417,7 +425,7 @@ main (int argc, char **argv)
 						t_smt = upper_age;
 					}
 					else {
-						fprintf (stderr, "%s: Seamounts near line %d has age (%lg) > oldest stage (%lg) (skipped)\n", GMT_program, n_read, t_smt, upper_age);
+						fprintf (stderr, "%s: Seamounts near line %d has age (%g) > oldest stage (%g) (skipped)\n", GMT_program, n_read, t_smt, upper_age);
 						continue;
 					}
 				}
@@ -499,10 +507,10 @@ main (int argc, char **argv)
 
 			if (gmtdefs.verbose && !(n_smts%100)) fprintf (stderr, "%s: Processed %5d seamounts\r", GMT_program, n_smts);
 		}
-		
+
 		if (fp != stdin) GMT_fclose (fp);
 	}
-	
+
 	/* OK, Done processing, time to write out */
 
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Processed %5d seamounts\n", GMT_program, n_smts);
@@ -524,8 +532,10 @@ main (int argc, char **argv)
 	GMT_free ((void *)ilatfactor);
 	GMT_free ((void *)xpos);
 	GMT_free ((void *)ypos);
-	
+
 	if (gmtdefs.verbose) fprintf (stderr, "%s: Done\n", GMT_program);
 
 	GMT_end (argc, argv);
+
+	exit (EXIT_SUCCESS);
 }
